==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Finalizat</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Axul de restricție...
</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>setează o restricție axială între două obiecte</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Auto evaluare...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Rulează o auto-evaluare pentru a verifica dacă aplicaţia funcţionează corespunzător</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>D&amp;esen</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>S&amp;chiţă</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Schiţare</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Bazat pe o schiţă</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitive</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametric</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Aparenţa obiectului</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Wire Tools</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Finalizat</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Axul de restricție...
</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>setează o restricție axială între două obiecte</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Auto evaluare...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Rulează o auto-evaluare pentru a verifica dacă aplicaţia funcţionează corespunzător</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>D&amp;esen</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>S&amp;chiţă</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Raytracing</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Schiţare</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Bazat pe o schiţă</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitive</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametric</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Aparenţa obiectului</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Instrumente pentru polilinii</translation>
    </message>
  </context>
</TS>
